from setuptools import setup, find_packages

setup(
    name="1RF21IS005",
    version="0.1",
    packages=find_packages(),
    install_requires=[
        # Any dependencies your project might have.
    ],
)
